﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;

namespace CoreRoutingExamples.Controllers
{
    [Produces("application/json")]
    [Route("api/Accounts/{AccountId}")]
    public class AccountsController : Controller
    {
        // http://localhost:27624/api/account/11
        public IActionResult Get(int accountId)
        {
            return Ok(accountId);
        }

        // http://localhost:27624/api/account/?accountId=11
        // http://localhost:27624/api/account/?accountId=11&AccountName=dave
        // http://localhost:27624/api/account/?accountId=11&AccountName=dave&managerid=15
        [HttpGet("/api/Account/")]
        public IActionResult Get(QueryModel queryModel)
        {
            return Ok(queryModel);
        }

        // http://localhost:27624/api/account/11/manager/22
        [HttpGet("Manager/{ManagerId}")]
        public IActionResult Get(int accountId, int managerId)
        {
            return Ok($"accountId:{accountId}, managerId:{managerId}");
        }

        // http://localhost:27624/api/account/11/manager/22/role/33
        [HttpGet("/api/Account/{AccountId}/Manager/{ManagerId}/Role/{RoleId}")]
        public IActionResult Get(int accountId, int managerId, int roleId)
        {
            return Ok($"accountId:{accountId}, managerId:{managerId}, roleId:{roleId}");
        }
    }

    public class QueryModel
    {
        public int AccountId { get; set; }
        public string AccountName { get; set; }
        public int ManagerId { get; set; }
    }
}